@@ -31,3 +31,8 @@ from sky_api_client.entity import constituent_online_presence  # noqa: F401
 from sky_api_client.entity import constituent_phone  # noqa: F401
 from sky_api_client.entity import constituent_code  # noqa: F401
 from sky_api_client.entity import constituent_relationship  # noqa: F401
+from sky_api_client.entity import gift_subtype  # noqa: F401
+from sky_api_client.entity import fundraising_appeal  # noqa: F401
+from sky_api_client.entity import fundraising_fund  # noqa: F401
+from sky_api_client.entity import fundraising_campaign  # noqa: F401
+from sky_api_client.entity import fundraising_package  # noqa: F401
