@@ -6,8 +6,6 @@ class EntityRegistry(object):
 
     @classmethod
     def register(cls, entity: str) -> Callable:
-        print(entity)
-
         def inner_wrapper(wrapped_class):
             cls.registry[entity] = wrapped_class
             return wrapped_class
@@ -16,7 +14,6 @@ class EntityRegistry(object):
 
     @classmethod
     def get_class(cls, entity: str, **kwargs):
-        print(cls.registry)
         if entity not in cls.registry:
             return None
         exec_class = cls.registry[entity]
